package com.aspose.imaging.examples;

import com.aspose.imaging.*;
import com.aspose.imaging.brushes.HatchBrush;
import com.aspose.imaging.createoptions.*;
import com.aspose.imaging.fileformats.psd.ColorModes;
import com.aspose.imaging.fileformats.psd.CompressionMethod;
import com.aspose.imaging.sources.StreamSource;

import java.io.*;

/**
 * Usage examples
 */
public class Examples
{
    public static void main(String[] args)
    {
        Examples.cacheExample();
        Examples.drawPngExample();
        Examples.fileCreateSourceExample();
        Examples.fileInputStreamExample();
        Examples.gifCreateOptionsExample();
        Examples.jpegCreateOptionsExample();
        Examples.psdSaveOptionsExample();
        Examples.penObjectsExample();
        Examples.rotate180FlipXExample();
        Examples.rotate180FlipXMemoryStreamPsdExample();
        Examples.rotate180FlipXPsdExample();
        Examples.shapesVarientyExample();
        Examples.solidBrushAndFontExample();
    }

    public static void cacheExample()
    {

        //ExStart
        //ExFor:com.aspose.imaging.Cache
        //ExSummary:This example demonstrates the use of com.aspose.imaging.Cache
        // By default the cache folder is set to user's local temp directory.
        // You can also specify another cache folder than default like the following:
        // Cache.CacheFolder = @"D:\\MyTemp";

        // Auto mode is flexible and efficient
        Cache.setCacheType(CacheType.Auto);

        // Default value is 0, which means there is no upper limit
        Cache.setMaxDiskSpaceForCache(1073741824); // 1 gigabyte
        Cache.setMaxMemoryForCache(1073741824); // 1 gigabyte

        // It is not recommended to change the following property as it may greatly affect the performance
        Cache.setExactReallocateOnly(false);

        // At any time you may check how many bytes currently allocated for memory or disk
        // cache by examining the following properties
        long l1 = Cache.getAllocatedDiskBytesCount();
        long l2 = Cache.getAllocatedMemoryBytesCount();

        // Do some image processing as below
        com.aspose.imaging.createoptions.GifCreateOptions options = new com.aspose.imaging.createoptions.GifCreateOptions();
        options.setWidth(100);
        options.setHeight(100);
        options.setPalette(new ColorPalette(new Color[]{Color.getRed(), Color.getBlue(), Color.getBlack(), Color.getWhite()}));
        options.setSource(new StreamSource(new ByteArrayInputStream(new byte[100 * 100 * 4 * 2]), true));
        try
        {
            RasterImage image = (RasterImage) Image.create(options);
            Color[] pixels = new Color[10000];
            for (int i = 0;
                 i < pixels.length;
                 i++)
            {
                pixels[i] = Color.getWhite();
            }

            image.savePixels(image.getBounds(), pixels);

            // after executing the code above there will be allocated 40000 bytes in-memory.
            long diskBytes = Cache.getAllocatedDiskBytesCount();
            long memoryBytes = Cache.getAllocatedMemoryBytesCount();
        }
        finally
        {
        }
        // The allocation properties may be used to check whether all Aspose.Imaging objects were properly disposed.
        // In case you've forgot to call dispose on some object the cache values will be different than 0.
        l1 = Cache.getAllocatedDiskBytesCount();
        l2 = Cache.getAllocatedMemoryBytesCount();
        //ExEnd
    }
    //ExStart
    //ExFor:com.aspose.imaging.Image.load(System.String)
    //ExSummary:This example demonstrates the loading of an existing Image file into an instance of com.aspose.imaging.Image using file path specified

    //Create Image instance and initialize it with an existing image file from disk location

//        com.aspose.imaging.Image image = com.aspose.imaging.Image.load(@"src\\resources\\sample.bmp");
    //ExEnd

    //ExStart
    //ExFor:com.aspose.imaging.sources.FileCreateSource.#ctor(System.String)
    //ExSummary:This example creates a new Image file at some disk location as specified by Source property of the BmpCreateOptions instance. If second parameter is not passed to the constructor of FileCreateSource, then by default the file to be created has property IsTemporal set to True. With IsTemporal set to True, no file will be saved on disk at the end of execution.
    public static void fileCreateSourceExample()
    {
        //Creates an instance of BmpCreateOptions and set its various properties
        com.aspose.imaging.createoptions.BmpCreateOptions createOptions = new com.aspose.imaging.createoptions.BmpCreateOptions();
        createOptions.setHeight(500);
        createOptions.setWidth(500);
        createOptions.setBitsPerPixel(24);

        //Create an instance of FileCreateSource and assign it as Source for the instance of BmpCreateOptions
        //If second parameter is not passed, then by default the file has IsTemporal set to True
        createOptions.setSource(new com.aspose.imaging.sources.FileCreateSource("src\\resources\\output.bmp"));

        //Creates an instance of Image
            com.aspose.imaging.Image image = com.aspose.imaging.Image.create(createOptions);
        //ExEnd
    }

    //ExStart
    //ExFor:com.aspose.imaging.Image.create(com.aspose.imaging.CreateOptions.ImageCreateOptions)
    //ExFor:com.aspose.imaging.sources.FileCreateSource.#ctor(System.String,System.Boolean)
    //ExFor:com.aspose.imaging.Image
    //ExFor:com.aspose.imaging.CreateOptions.BmpCreateOptions
    //ExSummary:This example creates a new Image file at some disk location as specified by Source property of the BmpCreateOptions instance. Several properties for BmpCreateOptions instance are set before creating the actual image. Especially the Source property, that refers to the actual disk location in this case.
    public static void fileInputStreamExample()
    {
        //Create an instance of BmpCreateOptions and set its various properties
        com.aspose.imaging.createoptions.BmpCreateOptions createOptions = new com.aspose.imaging.createoptions.BmpCreateOptions();
        createOptions.setHeight(500);
        createOptions.setWidth(500);
        createOptions.setBitsPerPixel(24);

        //Create an instance of FileCreateSource and assign it as Source for the instance of BmpCreateOptions
        //Second Boolean parameter determines if the file to be created IsTemporal or not
        createOptions.setSource(new com.aspose.imaging.sources.FileCreateSource("src\\resources\\sample.bmp", false));

        //Create an instance of Image and initialize it with instance of BmpCreateOptions by calling Create method
        com.aspose.imaging.Image image = com.aspose.imaging.Image.create(createOptions);
        //do some image processing
        //ExEnd

        //ExStart
        //ExFor:com.aspose.imaging.sources.StreamSource.#ctor(System.IO.Stream,System.Boolean)
        //ExFor:com.aspose.imaging.CreateOptions.JpegCreateOptions
        //ExSummary:This example demonstrates the use of System.IO.Stream to Create a new Image file (a JPEG type)

        //Creates an instance of JpegCreateOptions and set its various properties
    }

    public static void jpegCreateOptionsExample()
    {
        JpegCreateOptions createOptions = new JpegCreateOptions();
        createOptions.setHeight(500);
        createOptions.setWidth(500);

        //Create an instance of System.IO.Stream
        InputStream stream = null;
        try
        {
            stream = new FileInputStream("src\\resources\\sample.jpeg");
        }
        catch (FileNotFoundException e)
        {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }

        //Define the source property for the instance of JpegCreateOptions
        //Second boolean parameter determins if the Stream is disposed once get out of scope
        createOptions.setSource(new com.aspose.imaging.sources.StreamSource(stream, true));

        //Creates an instance of Image and call Create method with JpegCreateOptions as parameter to initialize the Image object
        com.aspose.imaging.Image image = com.aspose.imaging.Image.create(createOptions);
        //do some image processing
        //ExEnd

        //ExStart
        //ExFor:com.aspose.imaging.Image.load(System.IO.Stream)
        //ExSummary:This example demonstrates the use of System.IO.Stream objects to load an existing Image file

        //Create an instance of FileStream
        try
        {
            FileInputStream stream1 = null;
            try
            {
                stream1 = new FileInputStream("src\\resources\\sample.bmp");
            }
            catch (FileNotFoundException e)
            {
                e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
            }
            //Create an instance of Image class and load an existing file through FileStream object by calling Load method
            com.aspose.imaging.Image image1 = com.aspose.imaging.Image.load(stream1);
        }
        finally
        {
        }
        //ExEnd

    }

    public static void gifCreateOptionsExample()
    {

        //ExStart
        //ExFor:com.aspose.imaging.sources.StreamSource.#ctor(System.IO.Stream)
        //ExFor:com.aspose.imaging.RasterImage
        //ExFor:com.aspose.imaging.Rasterimage.loadPixels
        //ExFor:com.aspose.imaging.Rasterimage.savePixels
        //ExFor:com.aspose.imaging.CreateOptions.GifCreateOptions
        //ExSummary:This example shows how to Loads Pixel information in an Array of Type Color, manipulates the array and set it back to the image. To perform these operations, this example creates a new Image file (in GIF format) uisng MemoryStream object.

        //Create an instance of MemoryStream
        try
        {
            ByteArrayInputStream stream = new ByteArrayInputStream(new byte[500 * 500 * 4 * 2]);
            //Create an instance of GifCreateOptions and set its various properties including the Source property
            GifCreateOptions createOptions = new GifCreateOptions();
            createOptions.setHeight(500);
            createOptions.setWidth(500);
            createOptions.setSource(new com.aspose.imaging.sources.StreamSource(stream));

            //Create an instance of Image
            com.aspose.imaging.RasterImage image = (com.aspose.imaging.RasterImage) com.aspose.imaging.Image.create(createOptions);

            //Get the pixels of image by specifying the area as image boundary
            com.aspose.imaging.Color[] pixels = image.loadPixels(image.getBounds());

            //Loop over the Array and sets color of alrenative indexed pixel
            for (int index = 0;
                 index < pixels.length;
                 index++)
            {
                if (index % 2 == 0)
                {
                    //Set the indexed pixel color to yellow
                    pixels[index] = com.aspose.imaging.Color.getYellow();
                } else
                {
                    //Set the indexed pixel color to blue
                    pixels[index] = com.aspose.imaging.Color.getBlue();
                }
            }

            //Apply the pixel changes to the image
            image.savePixels(image.getBounds(), pixels);
            //Write MemoryStream to File
            byte[] buffer = new byte[stream.available()];
            stream.read(buffer, 0, buffer.length);
            FileOutputStream os = new FileOutputStream("src\\resources\\gifCreateOptionsExample.gif");

        }
        catch (FileNotFoundException e)
        {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }
        finally
        {
        }
    }
    //ExEnd

    //ExStart
    //ExFor:com.aspose.imaging.Image.RotateFlip
    //ExSummary:This example demonstrates the use of Rotate operation on an image. Example loads an existing image file from some disk location and performs the Rotate operaation on the image according to the value of Enum com.aspose.imaging.RotateFlipType

    //Create an instance of image class and initialize it with an existing image file through File path
    public static void rotate180FlipXExample()
    {
        com.aspose.imaging.Image image = com.aspose.imaging.Image.load("src\\resources\\sample.bmp");
        image.rotateFlip(com.aspose.imaging.RotateFlipType.Rotate180FlipX);
    }
    //ExEnd

    //ExStart
    //ExFor:com.aspose.imaging.image.save(System.String,com.aspose.imaging.SaveOptionsBase)
    //ExSummary:This example shows the simple steps to Save an Image. To demonstrate this operation, we load an existing file from some disk location, performs Rotate operation on the image and Save the image in PSD format using File Path
    public static void rotate180FlipXPsdExample()
    {
        com.aspose.imaging.Image image = com.aspose.imaging.Image.load("src\\resources\\sample.bmp");
        image.rotateFlip(com.aspose.imaging.RotateFlipType.Rotate180FlipX);
        //Save the Image as PSD to File Path with default PsdSaveOptions settings
        image.save("src\\resources\\output.psd", new com.aspose.imaging.saveoptions.PsdSaveOptions());
    }
    //ExEnd

    //ExStart
    //ExFor:com.aspose.imaging.image.save(System.IO.Stream,com.aspose.imaging.SaveOptionsBase)
    //ExSummary:This example shows the process of Saving an Image to MemoryStream. To demonstrate this operation, example loads an existing file from some disk location, performs Rotate operation on the image and Save the image in PSD format
    public static void rotate180FlipXMemoryStreamPsdExample()
    {
        com.aspose.imaging.Image image = com.aspose.imaging.Image.load("src\\resources\\sample.bmp");
        image.rotateFlip(com.aspose.imaging.RotateFlipType.Rotate180FlipX);
        //Save the Image as PSD to File Path with default PsdSaveOptions settings
        ByteArrayInputStream stream = new ByteArrayInputStream(new byte[image.getHeight() * image.getWidth() * 4 * 2]);
        //Save the Image as PSD to MemoryStream with default PsdSaveOptions settings
        image.save(stream, new com.aspose.imaging.saveoptions.PsdSaveOptions());
    }
    //ExEnd

    //ExStart
    //ExFor:com.aspose.imaging.saveoptions.PsdSaveOptions
    //ExSummary:This example demonstrates the use of Aspsoe.Imaging for .Net API to convert Images to PSD format. To achieve this goal this example loads an existing image and then saves it back to PSD format.

    public static void psdSaveOptionsExample()
    {
        //Creates an instance of image class and initialize it with an existing file through File path
        com.aspose.imaging.Image image = com.aspose.imaging.Image.load("src\\resources\\sample.bmp");
        //Create an instance of PsdSaveOptions class
        com.aspose.imaging.saveoptions.PsdSaveOptions saveOptions = new com.aspose.imaging.saveoptions.PsdSaveOptions();

        //Set the CompressionMethod as RLE
        //Note: Other supported CompressionMethod is CompressionMethod.RAW [No Compression]
        saveOptions.setCompressionMethod(CompressionMethod.RLE);

        //Set the ColorMode to GrayScale
        //Note: Other supported ColorModes are ColorModes.Bitmap and ColorModes.RGB
        saveOptions.setColorMode(ColorModes.Grayscale);

        //Save the image to disk location with supplied PsdSaveOptions settings
        image.save("src\\resources\\output.psd", saveOptions);
    }
    //ExEnd

    //ExStart
    //ExFor:com.aspose.imaging.sources.StreamSource
    //ExFor:com.aspose.imaging.Graphics
    //ExFor:com.aspose.imaging.CreateOptions.PngCreateOptions
    //ExFor:com.aspose.imaging.Brushes.SolidBrush
    //ExSummary:This example uses Graphics class to create primitive shapes on the Image surface. To demonstrate the operation, the example creates a new Image in PNG format and draw primitive shapes on Image surface using Draw methods exposed by Graphics class

    //Creates an instance of FileStream
    public static void drawPngExample()
    {
        InputStream stream = null;
        try
        {
            stream = new FileInputStream("src\\resources\\sample.png");
        }
        catch (FileNotFoundException e)
        {
            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
        }
        //Create an instance of PngCreateOptions and set its various properties
        PngCreateOptions createOptions = new PngCreateOptions();
        createOptions.setHeight(500);
        createOptions.setWidth(500);
        //Set the Source for PngCreateOptions
        createOptions.setSource(new com.aspose.imaging.sources.StreamSource(stream));

        //Create an instance of Image
        com.aspose.imaging.Image image = com.aspose.imaging.Image.create(createOptions);
        //Create and initialize an instance of Graphics class
        com.aspose.imaging.Graphics graphics = new com.aspose.imaging.Graphics(image);

        //Clear Graphics surface
        graphics.clear(Color.getWheat());

        //Draw an Arc by specifying the Pen object having Black color,
        //a Rectangle surrounding the Arc, Start Angle and Sweep Angle
        graphics.drawArc(new Pen(Color.getBlack(), 2), new Rectangle(200, 200, 100, 200), 0, 300);

        //Draw a Bezier by specifying the Pen object having Blue color and co-ordinate Points.
        graphics.drawBezier(new Pen(Color.getBlue(), 2), new Point(250, 100), new Point(300, 30), new Point(450, 100), new Point(235, 25));

        //Draw a Curve by specifying the Pen object having Green color and an array of Points
        graphics.drawCurve(new Pen(Color.getGreen(), 2), new Point[]{new Point(100, 200), new Point(100, 350), new Point(200, 450)});

        //Draw an Ellipse using the Pen object and a surrounding Rectangle
        graphics.drawEllipse(new Pen(Color.getYellow(), 2), new Rectangle(300, 300, 100, 100));

        //Draw a Line
        graphics.drawLine(new Pen(Color.getViolet(), 2), new Point(100, 100), new Point(200, 200));

        //Draw a Pie segment
        graphics.drawPie(new Pen(Color.getSilver(), 2), new Rectangle(new Point(200, 20), new Size(200, 200)), 0, 45);

        //Draw a Polygon by specifying the Pen object having Red color and an array of Points
        graphics.drawPolygon(new Pen(Color.getRed(), 2), new Point[]{new Point(20, 100), new Point(20, 200), new Point(220, 20)});

        //Draw a Rectangle
        graphics.drawRectangle(new Pen(Color.getOrange(), 2), new Rectangle(new Point(250, 250), new Size(100, 100)));

        //Create a SolidBrush object and set its various properties
        com.aspose.imaging.brushes.SolidBrush brush = new com.aspose.imaging.brushes.SolidBrush();
        brush.setColor(Color.getPurple());
        brush.setOpacity(100);

        //Draw a String using the SolidBrush object and Font, at specific Point
        graphics.drawString("This image is created by Aspose.Imaging API", new Font("Times New Roman", 16), brush, new PointF(50, 400));
    }
    //ExEnd

    //ExStart
    //ExFor:com.aspose.imaging.Pen
    //ExFor:com.aspose.imaging.graphics.drawRectangles(Pen,Rectangle[])
    //ExFor:com.aspose.imaging.Brushes.HatchBrush
    //ExSummary:This example shows the creation and usage Pen objects. The example creates a new Image and draw Rectangles on Image surface.
    public static void penObjectsExample()
    {
        //Create an instance of BmpCreateOptions and set its various properties
        BmpCreateOptions createOptions = new BmpCreateOptions();
        createOptions.setHeight(500);
        createOptions.setWidth(500);
        createOptions.setBitsPerPixel(24);

        //Create an instance of FileCreateSource and assign it as Source for the instance of BmpCreateOptions
        //Second Boolean parameter determines if the file to be created IsTemporal or not
        createOptions.setSource(new com.aspose.imaging.sources.FileCreateSource("src\\resources\\sample.bmp", false));

        //Create an instance of Image at specified Path
        com.aspose.imaging.Image image = com.aspose.imaging.Image.create(createOptions);
        //Create an instance of Graphics and initialize it with Image object
        com.aspose.imaging.Graphics graphics = new com.aspose.imaging.Graphics(image);

        //Clear the Graphics sutface with White Color
        graphics.clear(com.aspose.imaging.Color.getWhite());

        //Create an instance of Pen with color Red and width 5
        com.aspose.imaging.Pen pen = new Pen(com.aspose.imaging.Color.getRed(), 5);

        //Create an instance of HatchBrush and set its properties
        com.aspose.imaging.brushes.HatchBrush brush = new HatchBrush();
        brush.setBackgroundColor(Color.getWheat());
        brush.setForegroundColor(Color.getRed());

        //Create an instance of Pen
        //initialize it with HatchBrush object and width
        com.aspose.imaging.Pen brusedpen = new Pen(brush, 5);

        //Draw Rectangles by specifying Pen object
        graphics.drawRectangles(pen, new Rectangle[]{new Rectangle(new Point(210, 210), new Size(100, 100)), new Rectangle(new Point(110, 110), new Size(100, 100)), new Rectangle(new Point(310, 310), new Size(100, 100))});

        //Draw Rectangles by specifying Pen object
        graphics.drawRectangles(brusedpen, new Rectangle[]{new Rectangle(new Point(310, 110), new Size(100, 100)), new Rectangle(new Point(110, 310), new Size(100, 100))});
    }
    //ExEnd

    //ExStart
    //ExFor:com.aspose.imaging.GraphicsPath.AddFigures
    //ExFor:com.aspose.imaging.figure.addShapes
    //ExFor:com.aspose.imaging.shapes.EllipseShape
    //ExFor:com.aspose.imaging.shapes.PieShape
    //ExFor:com.aspose.imaging.shapes.ArcShape
    //ExFor:com.aspose.imaging.shapes.PolygonShape
    //ExFor:com.aspose.imaging.shapes.RectangleShape
    //ExSummary:This example creates a new Image and draws a variety of shapes using Figures and GraphicsPath on the Image surface

    public static void shapesVarientyExample()
    {
        //Creates an instance of BmpCreateOptions and set its various properties
        BmpCreateOptions createOptions = new BmpCreateOptions();
        createOptions.setHeight(500);
        createOptions.setWidth(500);
        createOptions.setBitsPerPixel(24);

        //Create an instance of FileCreateSource and assign it as Source for the instance of BmpCreateOptions
        //Second Boolean parameter determines if the file to be created IsTemporal or not
        createOptions.setSource(new com.aspose.imaging.sources.FileCreateSource("src\\resources\\output.bmp", false));

        //Create an instance of Image
        com.aspose.imaging.Image image = com.aspose.imaging.Image.create(createOptions);

        //Create and initialize an instance of Graphics class
        com.aspose.imaging.Graphics graphics = new com.aspose.imaging.Graphics(image);

        //Clear Graphics surface
        graphics.clear(Color.getWheat());

        //Create an instance of GraphicsPath class
        com.aspose.imaging.GraphicsPath graphicspath = new com.aspose.imaging.GraphicsPath();

        //Create an instance of Figure class
        com.aspose.imaging.Figure figure1 = new com.aspose.imaging.Figure();

        //Add Shape to Figure object
        figure1.addShape(new com.aspose.imaging.shapes.EllipseShape(new RectangleF(50, 50, 300, 300)));
        figure1.addShape(new com.aspose.imaging.shapes.PieShape(new RectangleF(new PointF(110, 110), new SizeF(200, 200)), 0, 90));

        //Create an instance of Figure class
        com.aspose.imaging.Figure figure2 = new com.aspose.imaging.Figure();

        //Add Shape to Figure object
        figure2.addShape(new com.aspose.imaging.shapes.ArcShape(new RectangleF(10, 10, 300, 300), 0, 45));
        figure2.addShape(new com.aspose.imaging.shapes.PolygonShape(new PointF[]{new PointF(150, 10), new PointF(150, 200), new PointF(250, 300), new PointF(350, 400)}, true));
        figure2.addShape(new com.aspose.imaging.shapes.RectangleShape(new RectangleF(new PointF(250, 250), new SizeF(200, 200))));

        //Add Figure object to GraphicsPath
        graphicspath.addFigures(new Figure[]{figure1, figure2});

        //Draw path with Pen object of color Black
        graphics.drawPath(new Pen(com.aspose.imaging.Color.getBlack(), 2), graphicspath);
    }
    //ExEnd

    //ExStart
    //ExFor:com.aspose.imaging.Font
    //ExFor:com.aspose.imaging.sources.FileCreateSource
    //ExFor:com.aspose.imaging.graphics.drawString(System.String,com.aspose.imaging.Font,com.aspose.imaging.Brush,com.aspose.imaging.PointF)
    //ExSummary:This example demonstrates the use of Font and SolidBrush class to draw strings on Image surface. The example creates a new Image and draw shapes using Figures and GraphicsPath

    public static void solidBrushAndFontExample()
    {
        //Creates an instance of BmpCreateOptions and set its various properties
        BmpCreateOptions createOptions = new BmpCreateOptions();
        createOptions.setHeight(500);
        createOptions.setWidth(500);
        createOptions.setBitsPerPixel(24);

        //Create an instance of FileCreateSource and assign it as Source for the instance of BmpCreateOptions
        //Second Boolean parameter determines if the file to be created IsTemporal or not
        createOptions.setSource(new com.aspose.imaging.sources.FileCreateSource("src\\resources\\sample.bmp", false));

        //Creates an instance of Image
        com.aspose.imaging.Image image = com.aspose.imaging.Image.create(createOptions);

        //Creates and initialize an instance of Graphics class
        com.aspose.imaging.Graphics graphics = new com.aspose.imaging.Graphics(image);

        //Clears Graphics surface
        graphics.clear(Color.getWheat());

        //Creates an instance of Font
        com.aspose.imaging.Font font = new com.aspose.imaging.Font("Times New Roman", 16);

        //Create an instance of SolidBrush having Red Color
        com.aspose.imaging.brushes.SolidBrush brush = new com.aspose.imaging.brushes.SolidBrush(Color.getRed());

        //Draw a String
        graphics.drawString("Created by Aspose.Imaging for .Net", font, brush, new PointF(100, 100));

        //ExEnd
    }

}

